import { Box } from "@chakra-ui/react";
import { usersRequestList } from "@/app/lib/users/action";
import { getIbcRequestList } from "@/app/lib/ibc/action";
import { prepareIbcDropdown, prepareUsersDropdown } from "@/utils/common";
import { SearchParamProps } from "@/types/searchParams";
import ReportsTable from "./components/table";
import { getAllReports } from "@/app/lib/reports/action";

const List = async ({ searchParams }: SearchParamProps) => {
  const [reports, users, ibcs] = await Promise.all([
    getAllReports(searchParams),
    usersRequestList({ pagination: "false" }),
    getIbcRequestList({ pagination: "false" }),
  ]);

  // Prepare data for users dropdown
  const usersDropdown = prepareUsersDropdown(users);

  // Prepare data for IBC dropdown
  const ibcsDropdown = prepareIbcDropdown(ibcs);

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      {reports?.data && (
        <ReportsTable
          data={reports.data}
          users={usersDropdown}
          ibcs={ibcsDropdown}
        />
      )}
    </Box>
  );
};

export default List;
